"""
Tests for wrapper for GarlandTools Job Enum
"""

from . import Job


def test_paladin_matches_abbreviation():
    """
    Tests if the Paladin job matches the abbreviation
    """
    assert Job.PALADIN == 'PLD'


def test_warrior_matches_abbreviation():
    """
    Tests if the Warrior job matches the abbreviation
    """
    assert Job.WARRIOR == 'WAR'


def test_dark_knight_matches_abbreviation():
    """
    Tests if the Dark Knight job matches the abbreviation
    """
    assert Job.DARK_KNIGHT == 'DRK'


def test_gun_breaker_matches_abbreviation():
    """
    Tests if the Gun Breaker job matches the abbreviation
    """
    assert Job.GUN_BREAKER == 'GNB'


def test_white_mage_matches_abbreviation():
    """
    Tests if the White Mage job matches the abbreviation
    """
    assert Job.WHITE_MAGE == 'WHM'


def test_scholar_matches_abbreviation():
    """
    Tests if the Scholar job matches the abbreviation
    """
    assert Job.SCHOLAR == 'SCH'


def test_astrologian_matches_abbreviation():
    """
    Tests if the Astrologian job matches the abbreviation
    """
    assert Job.ASTROLOGIAN == 'AST'


def test_sage_matches_abbreviation():
    """
    Tests if the Sage job matches the abbreviation
    """
    assert Job.SAGE == 'SGE'


def test_monk_matches_abbreviation():
    """
    Tests if the Monk job matches the abbreviation
    """
    assert Job.MONK == 'MNK'


def test_dragoon_matches_abbreviation():
    """
    Tests if the Dragoon job matches the abbreviation
    """
    assert Job.DRAGOON == 'DRG'


def test_ninja_matches_abbreviation():
    """
    Tests if the Ninja job matches the abbreviation
    """
    assert Job.NINJA == 'NIN'


def test_samurai_matches_abbreviation():
    """
    Tests if the Samurai job matches the abbreviation
    """
    assert Job.SAMURAI == 'SAM'


def test_reaper_matches_abbreviation():
    """
    Tests if the Reaper job matches the abbreviation
    """
    assert Job.REAPER == 'RPR'


def test_bard_matches_abbreviation():
    """
    Tests if the Bard job matches the abbreviation
    """
    assert Job.BARD == 'BRD'


def test_machinist_matches_abbreviation():
    """
    Tests if the Machinist job matches the abbreviation
    """
    assert Job.MACHINIST == 'MCH'


def test_dancer_matches_abbreviation():
    """
    Tests if the Dancer job matches the abbreviation
    """
    assert Job.DANCER == 'DNC'


def test_black_mage_matches_abbreviation():
    """
    Tests if the Black Mage job matches the abbreviation
    """
    assert Job.BLACK_MAGE == 'BLM'


def test_summoner_matches_abbreviation():
    """
    Tests if the Summoner job matches the abbreviation
    """
    assert Job.SUMMONER == 'SMN'


def test_red_mage_matches_abbreviation():
    """
    Tests if the Red Mage job matches the abbreviation
    """
    assert Job.RED_MAGE == 'RDM'


def test_blue_mage_matches_abbreviation():
    """
    Tests if the Blue Mage job matches the abbreviation
    """
    assert Job.BLUE_MAGE == 'BLU'


def test_carpenter_matches_abbreviation():
    """
    Tests if the Carpenter job matches the abbreviation
    """
    assert Job.CARPENTER == 'CRP'


def test_blacksmith_matches_abbreviation():
    """
    Tests if the Blacksmith job matches the abbreviation
    """
    assert Job.BLACKSMITH == 'BSM'


def test_armorer_matches_abbreviation():
    """
    Tests if the Armorer job matches the abbreviation
    """
    assert Job.ARMORER == 'ARM'


def test_goldsmith_matches_abbreviation():
    """
    Tests if the Goldsmith job matches the abbreviation
    """
    assert Job.GOLDSMITH == 'GSM'


def test_leatherworker_matches_abbreviation():
    """
    Tests if the Leatherworker job matches the abbreviation
    """
    assert Job.LEATHERWORKER == 'LTW'


def test_weaver_matches_abbreviation():
    """
    Tests if the Weaver job matches the abbreviation
    """
    assert Job.WEAVER == 'WVR'


def test_alchemist_matches_abbreviation():
    """
    Tests if the Alchemist job matches the abbreviation
    """
    assert Job.ALCHEMIST == 'ALC'


def test_culinarian_matches_abbreviation():
    """
    Tests if the Culinarian job matches the abbreviation
    """
    assert Job.CULINARIAN == 'CUL'


def test_miner_matches_abbreviation():
    """
    Tests if the Miner job matches the abbreviation
    """
    assert Job.MINER == 'MIN'


def test_botanist_matches_abbreviation():
    """
    Tests if the Botanist job matches the abbreviation
    """
    assert Job.BOTANIST == 'BTN'


def test_fisher_matches_abbreviation():
    """
    Tests if the Fisher job matches the abbreviation
    """
    assert Job.FISHER == 'FSH'
